"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MessageType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _MessageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MessageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REPLY: _MessageType.ValueType  # 0
    INFO: _MessageType.ValueType  # 1
    ALERT: _MessageType.ValueType  # 2
class MessageType(_MessageType, metaclass=_MessageTypeEnumTypeWrapper):
    """---- Enums ----

    """
    pass

REPLY: MessageType.ValueType  # 0
INFO: MessageType.ValueType  # 1
ALERT: MessageType.ValueType  # 2
global___MessageType = MessageType


class _Errors:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ErrorsEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Errors.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REQUEST_TIMEOUT: _Errors.ValueType  # 0
    CONNECTION_CLOSED: _Errors.ValueType  # 1
    INVALID_ARGUMENT: _Errors.ValueType  # 2
    OUT_OF_REQUEST_IDS: _Errors.ValueType  # 3
    INVALID_PACKET: _Errors.ValueType  # 4
    CONNECTION_FAILED: _Errors.ValueType  # 5
    UNKNOWN_REQUEST: _Errors.ValueType  # 6
    COMMAND_FAILED: _Errors.ValueType  # 7
    DEVICE_DB_FAILED: _Errors.ValueType  # 8
    INVALID_DATA: _Errors.ValueType  # 9
    DEVICE_NOT_IDENTIFIED: _Errors.ValueType  # 10
    CONVERSION_FAILED: _Errors.ValueType  # 11
    DEVICE_ADDRESS_CONFLICT: _Errors.ValueType  # 12
    NO_DEVICE_FOUND: _Errors.ValueType  # 13
    MOVEMENT_INTERRUPTED: _Errors.ValueType  # 14
    MOVEMENT_FAILED: _Errors.ValueType  # 15
    IO_FAILED: _Errors.ValueType  # 16
    INVALID_RESPONSE: _Errors.ValueType  # 17
    NOT_SUPPORTED: _Errors.ValueType  # 18
    DEVICE_FAILED: _Errors.ValueType  # 19
    OS_FAILED: _Errors.ValueType  # 20
    INTERNAL_ERROR: _Errors.ValueType  # 22
    BINARY_COMMAND_FAILED: _Errors.ValueType  # 24
    COMMAND_PREEMPTED: _Errors.ValueType  # 25
    LOCKSTEP_NOT_ENABLED: _Errors.ValueType  # 26
    LOCKSTEP_ENABLED: _Errors.ValueType  # 27
    IO_CHANNEL_OUT_OF_RANGE: _Errors.ValueType  # 28
    SETTING_NOT_FOUND: _Errors.ValueType  # 29
    STREAM_MODE: _Errors.ValueType  # 30
    STREAM_EXECUTION: _Errors.ValueType  # 31
    STREAM_MOVEMENT_FAILED: _Errors.ValueType  # 32
    STREAM_SETUP_FAILED: _Errors.ValueType  # 33
    DEVICE_BUSY: _Errors.ValueType  # 34
    STREAM_MOVEMENT_INTERRUPTED: _Errors.ValueType  # 35
    INVALID_PARK_STATE: _Errors.ValueType  # 36
    SERIAL_PORT_BUSY: _Errors.ValueType  # 37
    TRANSPORT_ALREADY_USED: _Errors.ValueType  # 38
    SET_PERIPHERAL_STATE_FAILED: _Errors.ValueType  # 39
    SET_DEVICE_STATE_FAILED: _Errors.ValueType  # 40
    G_CODE_SYNTAX: _Errors.ValueType  # 41
    G_CODE_EXECUTION: _Errors.ValueType  # 42
    INVALID_OPERATION: _Errors.ValueType  # 43
    COMMAND_TOO_LONG: _Errors.ValueType  # 44
    NO_VALUE_FOR_KEY: _Errors.ValueType  # 45
class Errors(_Errors, metaclass=_ErrorsEnumTypeWrapper):
    pass

REQUEST_TIMEOUT: Errors.ValueType  # 0
CONNECTION_CLOSED: Errors.ValueType  # 1
INVALID_ARGUMENT: Errors.ValueType  # 2
OUT_OF_REQUEST_IDS: Errors.ValueType  # 3
INVALID_PACKET: Errors.ValueType  # 4
CONNECTION_FAILED: Errors.ValueType  # 5
UNKNOWN_REQUEST: Errors.ValueType  # 6
COMMAND_FAILED: Errors.ValueType  # 7
DEVICE_DB_FAILED: Errors.ValueType  # 8
INVALID_DATA: Errors.ValueType  # 9
DEVICE_NOT_IDENTIFIED: Errors.ValueType  # 10
CONVERSION_FAILED: Errors.ValueType  # 11
DEVICE_ADDRESS_CONFLICT: Errors.ValueType  # 12
NO_DEVICE_FOUND: Errors.ValueType  # 13
MOVEMENT_INTERRUPTED: Errors.ValueType  # 14
MOVEMENT_FAILED: Errors.ValueType  # 15
IO_FAILED: Errors.ValueType  # 16
INVALID_RESPONSE: Errors.ValueType  # 17
NOT_SUPPORTED: Errors.ValueType  # 18
DEVICE_FAILED: Errors.ValueType  # 19
OS_FAILED: Errors.ValueType  # 20
INTERNAL_ERROR: Errors.ValueType  # 22
BINARY_COMMAND_FAILED: Errors.ValueType  # 24
COMMAND_PREEMPTED: Errors.ValueType  # 25
LOCKSTEP_NOT_ENABLED: Errors.ValueType  # 26
LOCKSTEP_ENABLED: Errors.ValueType  # 27
IO_CHANNEL_OUT_OF_RANGE: Errors.ValueType  # 28
SETTING_NOT_FOUND: Errors.ValueType  # 29
STREAM_MODE: Errors.ValueType  # 30
STREAM_EXECUTION: Errors.ValueType  # 31
STREAM_MOVEMENT_FAILED: Errors.ValueType  # 32
STREAM_SETUP_FAILED: Errors.ValueType  # 33
DEVICE_BUSY: Errors.ValueType  # 34
STREAM_MOVEMENT_INTERRUPTED: Errors.ValueType  # 35
INVALID_PARK_STATE: Errors.ValueType  # 36
SERIAL_PORT_BUSY: Errors.ValueType  # 37
TRANSPORT_ALREADY_USED: Errors.ValueType  # 38
SET_PERIPHERAL_STATE_FAILED: Errors.ValueType  # 39
SET_DEVICE_STATE_FAILED: Errors.ValueType  # 40
G_CODE_SYNTAX: Errors.ValueType  # 41
G_CODE_EXECUTION: Errors.ValueType  # 42
INVALID_OPERATION: Errors.ValueType  # 43
COMMAND_TOO_LONG: Errors.ValueType  # 44
NO_VALUE_FOR_KEY: Errors.ValueType  # 45
global___Errors = Errors


class _InterfaceType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _InterfaceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InterfaceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SERIAL_PORT: _InterfaceType.ValueType  # 0
    TCP: _InterfaceType.ValueType  # 1
    CUSTOM: _InterfaceType.ValueType  # 2
    IOT: _InterfaceType.ValueType  # 3
    NETWORK_SHARE: _InterfaceType.ValueType  # 4
class InterfaceType(_InterfaceType, metaclass=_InterfaceTypeEnumTypeWrapper):
    pass

SERIAL_PORT: InterfaceType.ValueType  # 0
TCP: InterfaceType.ValueType  # 1
CUSTOM: InterfaceType.ValueType  # 2
IOT: InterfaceType.ValueType  # 3
NETWORK_SHARE: InterfaceType.ValueType  # 4
global___InterfaceType = InterfaceType


class Request(google.protobuf.message.Message):
    """---- Types ----

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REQUEST_FIELD_NUMBER: builtins.int
    request: typing.Text
    def __init__(self,
        *,
        request: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request",b"request"]) -> None: ...
global___Request = Request

class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _ResponseType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _ResponseTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Response._ResponseType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OK: Response._ResponseType.ValueType  # 0
        ERROR: Response._ResponseType.ValueType  # 1
    class ResponseType(_ResponseType, metaclass=_ResponseTypeEnumTypeWrapper):
        pass

    OK: Response.ResponseType.ValueType  # 0
    ERROR: Response.ResponseType.ValueType  # 1

    RESPONSE_FIELD_NUMBER: builtins.int
    ERROR_TYPE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    response: global___Response.ResponseType.ValueType
    error_type: global___Errors.ValueType
    error_message: typing.Text
    def __init__(self,
        *,
        response: global___Response.ResponseType.ValueType = ...,
        error_type: global___Errors.ValueType = ...,
        error_message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message",b"error_message","error_type",b"error_type","response",b"response"]) -> None: ...
global___Response = Response

class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_FIELD_NUMBER: builtins.int
    event: typing.Text
    def __init__(self,
        *,
        event: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event",b"event"]) -> None: ...
global___Event = Event

class EmptyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___EmptyRequest = EmptyRequest

class BoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(self,
        *,
        value: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value",b"value"]) -> None: ...
global___BoolResponse = BoolResponse

class DoubleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    def __init__(self,
        *,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value",b"value"]) -> None: ...
global___DoubleResponse = DoubleResponse

class IntResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(self,
        *,
        value: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value",b"value"]) -> None: ...
global___IntResponse = IntResponse

class StringResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    value: typing.Text
    def __init__(self,
        *,
        value: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value",b"value"]) -> None: ...
global___StringResponse = StringResponse

class AxisIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _AxisType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _AxisTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AxisIdentity._AxisType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: AxisIdentity._AxisType.ValueType  # 0
        LINEAR: AxisIdentity._AxisType.ValueType  # 1
        ROTARY: AxisIdentity._AxisType.ValueType  # 2
    class AxisType(_AxisType, metaclass=_AxisTypeEnumTypeWrapper):
        pass

    UNKNOWN: AxisIdentity.AxisType.ValueType  # 0
    LINEAR: AxisIdentity.AxisType.ValueType  # 1
    ROTARY: AxisIdentity.AxisType.ValueType  # 2

    IS_PERIPHERAL_FIELD_NUMBER: builtins.int
    PERIPHERAL_ID_FIELD_NUMBER: builtins.int
    PERIPHERAL_NAME_FIELD_NUMBER: builtins.int
    AXIS_TYPE_FIELD_NUMBER: builtins.int
    IS_MODIFIED_FIELD_NUMBER: builtins.int
    is_peripheral: builtins.bool
    peripheral_id: builtins.int
    peripheral_name: typing.Text
    axis_type: global___AxisIdentity.AxisType.ValueType
    is_modified: builtins.bool
    def __init__(self,
        *,
        is_peripheral: builtins.bool = ...,
        peripheral_id: builtins.int = ...,
        peripheral_name: typing.Text = ...,
        axis_type: global___AxisIdentity.AxisType.ValueType = ...,
        is_modified: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_type",b"axis_type","is_modified",b"is_modified","is_peripheral",b"is_peripheral","peripheral_id",b"peripheral_id","peripheral_name",b"peripheral_name"]) -> None: ...
global___AxisIdentity = AxisIdentity

class DeviceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ID_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AXIS_COUNT_FIELD_NUMBER: builtins.int
    FIRMWARE_VERSION_FIELD_NUMBER: builtins.int
    IS_MODIFIED_FIELD_NUMBER: builtins.int
    IS_INTEGRATED_FIELD_NUMBER: builtins.int
    device_id: builtins.int
    serial_number: builtins.int
    name: typing.Text
    axis_count: builtins.int
    @property
    def firmware_version(self) -> global___FirmwareVersion: ...
    is_modified: builtins.bool
    is_integrated: builtins.bool
    def __init__(self,
        *,
        device_id: builtins.int = ...,
        serial_number: builtins.int = ...,
        name: typing.Text = ...,
        axis_count: builtins.int = ...,
        firmware_version: typing.Optional[global___FirmwareVersion] = ...,
        is_modified: builtins.bool = ...,
        is_integrated: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["firmware_version",b"firmware_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_count",b"axis_count","device_id",b"device_id","firmware_version",b"firmware_version","is_integrated",b"is_integrated","is_modified",b"is_modified","name",b"name","serial_number",b"serial_number"]) -> None: ...
global___DeviceIdentity = DeviceIdentity

class FirmwareVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MAJOR_FIELD_NUMBER: builtins.int
    MINOR_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    major: builtins.int
    minor: builtins.int
    build: builtins.int
    def __init__(self,
        *,
        major: builtins.int = ...,
        minor: builtins.int = ...,
        build: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build",b"build","major",b"major","minor",b"minor"]) -> None: ...
global___FirmwareVersion = FirmwareVersion

class DeviceIOInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NUMBER_ANALOG_OUTPUTS_FIELD_NUMBER: builtins.int
    NUMBER_ANALOG_INPUTS_FIELD_NUMBER: builtins.int
    NUMBER_DIGITAL_OUTPUTS_FIELD_NUMBER: builtins.int
    NUMBER_DIGITAL_INPUTS_FIELD_NUMBER: builtins.int
    number_analog_outputs: builtins.int
    number_analog_inputs: builtins.int
    number_digital_outputs: builtins.int
    number_digital_inputs: builtins.int
    def __init__(self,
        *,
        number_analog_outputs: builtins.int = ...,
        number_analog_inputs: builtins.int = ...,
        number_digital_outputs: builtins.int = ...,
        number_digital_inputs: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["number_analog_inputs",b"number_analog_inputs","number_analog_outputs",b"number_analog_outputs","number_digital_inputs",b"number_digital_inputs","number_digital_outputs",b"number_digital_outputs"]) -> None: ...
global___DeviceIOInfo = DeviceIOInfo

class Measurement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    value: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        value: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["unit",b"unit","value",b"value"]) -> None: ...
global___Measurement = Measurement

class StreamAxisDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    AXIS_TYPE_FIELD_NUMBER: builtins.int
    axis_number: builtins.int
    axis_type: builtins.int
    def __init__(self,
        *,
        axis_number: builtins.int = ...,
        axis_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","axis_type",b"axis_type"]) -> None: ...
global___StreamAxisDefinition = StreamAxisDefinition

class InvalidPacketExceptionData(google.protobuf.message.Message):
    """---- Exceptions ----

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PACKET_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    packet: typing.Text
    reason: typing.Text
    def __init__(self,
        *,
        packet: typing.Text = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["packet",b"packet","reason",b"reason"]) -> None: ...
global___InvalidPacketExceptionData = InvalidPacketExceptionData

class DeviceAddressConflictExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ADDRESSES_FIELD_NUMBER: builtins.int
    @property
    def device_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        device_addresses: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_addresses",b"device_addresses"]) -> None: ...
global___DeviceAddressConflictExceptionData = DeviceAddressConflictExceptionData

class MovementInterruptedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WARNINGS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    @property
    def warnings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    reason: typing.Text
    def __init__(self,
        *,
        warnings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reason",b"reason","warnings",b"warnings"]) -> None: ...
global___MovementInterruptedExceptionData = MovementInterruptedExceptionData

class StreamMovementInterruptedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WARNINGS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    @property
    def warnings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    reason: typing.Text
    def __init__(self,
        *,
        warnings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reason",b"reason","warnings",b"warnings"]) -> None: ...
global___StreamMovementInterruptedExceptionData = StreamMovementInterruptedExceptionData

class MovementFailedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WARNINGS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    @property
    def warnings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    reason: typing.Text
    def __init__(self,
        *,
        warnings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reason",b"reason","warnings",b"warnings"]) -> None: ...
global___MovementFailedExceptionData = MovementFailedExceptionData

class StreamMovementFailedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    WARNINGS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    @property
    def warnings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    reason: typing.Text
    def __init__(self,
        *,
        warnings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reason",b"reason","warnings",b"warnings"]) -> None: ...
global___StreamMovementFailedExceptionData = StreamMovementFailedExceptionData

class StreamExecutionExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ERROR_FLAG_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    error_flag: typing.Text
    reason: typing.Text
    def __init__(self,
        *,
        error_flag: typing.Text = ...,
        reason: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_flag",b"error_flag","reason",b"reason"]) -> None: ...
global___StreamExecutionExceptionData = StreamExecutionExceptionData

class InvalidResponseExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RESPONSE_FIELD_NUMBER: builtins.int
    response: typing.Text
    def __init__(self,
        *,
        response: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["response",b"response"]) -> None: ...
global___InvalidResponseExceptionData = InvalidResponseExceptionData

class CommandFailedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RESPONSE_DATA_FIELD_NUMBER: builtins.int
    REPLY_FLAG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WARNING_FLAG_FIELD_NUMBER: builtins.int
    response_data: typing.Text
    reply_flag: typing.Text
    status: typing.Text
    warning_flag: typing.Text
    def __init__(self,
        *,
        response_data: typing.Text = ...,
        reply_flag: typing.Text = ...,
        status: typing.Text = ...,
        warning_flag: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["reply_flag",b"reply_flag","response_data",b"response_data","status",b"status","warning_flag",b"warning_flag"]) -> None: ...
global___CommandFailedExceptionData = CommandFailedExceptionData

class BinaryCommandFailedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RESPONSE_DATA_FIELD_NUMBER: builtins.int
    response_data: builtins.int
    def __init__(self,
        *,
        response_data: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["response_data",b"response_data"]) -> None: ...
global___BinaryCommandFailedExceptionData = BinaryCommandFailedExceptionData

class SetPeripheralStateExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    SERVO_TUNING_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    axis_number: builtins.int
    @property
    def settings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    servo_tuning: typing.Text
    @property
    def storage(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        axis_number: builtins.int = ...,
        settings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        servo_tuning: typing.Text = ...,
        storage: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","servo_tuning",b"servo_tuning","settings",b"settings","storage",b"storage"]) -> None: ...
global___SetPeripheralStateExceptionData = SetPeripheralStateExceptionData

class SetDeviceStateExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PERIPHERALS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    STREAM_BUFFERS_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    IP_CONFIG_FIELD_NUMBER: builtins.int
    SERVO_TUNING_FIELD_NUMBER: builtins.int
    STORAGE_FIELD_NUMBER: builtins.int
    @property
    def peripherals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SetPeripheralStateExceptionData]: ...
    @property
    def settings(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def stream_buffers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    ip_config: typing.Text
    servo_tuning: typing.Text
    @property
    def storage(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        peripherals: typing.Optional[typing.Iterable[global___SetPeripheralStateExceptionData]] = ...,
        settings: typing.Optional[typing.Iterable[typing.Text]] = ...,
        stream_buffers: typing.Optional[typing.Iterable[typing.Text]] = ...,
        triggers: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ip_config: typing.Text = ...,
        servo_tuning: typing.Text = ...,
        storage: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_config",b"ip_config","peripherals",b"peripherals","servo_tuning",b"servo_tuning","settings",b"settings","storage",b"storage","stream_buffers",b"stream_buffers","triggers",b"triggers"]) -> None: ...
global___SetDeviceStateExceptionData = SetDeviceStateExceptionData

class CommandTooLongExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FIT_FIELD_NUMBER: builtins.int
    REMAINDER_FIELD_NUMBER: builtins.int
    PACKET_SIZE_FIELD_NUMBER: builtins.int
    PACKETS_MAX_FIELD_NUMBER: builtins.int
    fit: typing.Text
    remainder: typing.Text
    packet_size: builtins.int
    packets_max: builtins.int
    def __init__(self,
        *,
        fit: typing.Text = ...,
        remainder: typing.Text = ...,
        packet_size: builtins.int = ...,
        packets_max: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fit",b"fit","packet_size",b"packet_size","packets_max",b"packets_max","remainder",b"remainder"]) -> None: ...
global___CommandTooLongExceptionData = CommandTooLongExceptionData

class TestRequest(google.protobuf.message.Message):
    """---- /test ----

    test/request
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RETURN_ERROR_FIELD_NUMBER: builtins.int
    DATA_PING_FIELD_NUMBER: builtins.int
    RETURN_ERROR_WITH_DATA_FIELD_NUMBER: builtins.int
    return_error: builtins.bool
    data_ping: typing.Text
    return_error_with_data: builtins.bool
    def __init__(self,
        *,
        return_error: builtins.bool = ...,
        data_ping: typing.Text = ...,
        return_error_with_data: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_ping",b"data_ping","return_error",b"return_error","return_error_with_data",b"return_error_with_data"]) -> None: ...
global___TestRequest = TestRequest

class TestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_PONG_FIELD_NUMBER: builtins.int
    data_pong: typing.Text
    def __init__(self,
        *,
        data_pong: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_pong",b"data_pong"]) -> None: ...
global___TestResponse = TestResponse

class TestResponseLong(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_PONG_FIELD_NUMBER: builtins.int
    @property
    def data_pong(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        data_pong: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_pong",b"data_pong"]) -> None: ...
global___TestResponseLong = TestResponseLong

class TestEvent(google.protobuf.message.Message):
    """test/event"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_FIELD_NUMBER: builtins.int
    data: typing.Text
    def __init__(self,
        *,
        data: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data"]) -> None: ...
global___TestEvent = TestEvent

class ToolsListSerialPortsResponse(google.protobuf.message.Message):
    """---- /tools ----

    tools/list_serial_ports
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PORTS_FIELD_NUMBER: builtins.int
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        ports: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ports",b"ports"]) -> None: ...
global___ToolsListSerialPortsResponse = ToolsListSerialPortsResponse

class SetDeviceDbSourceRequest(google.protobuf.message.Message):
    """---- /device_db ----

    device_db/set_source
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOURCE_TYPE_FIELD_NUMBER: builtins.int
    URL_OR_FILE_PATH_FIELD_NUMBER: builtins.int
    source_type: builtins.int
    url_or_file_path: typing.Text
    def __init__(self,
        *,
        source_type: builtins.int = ...,
        url_or_file_path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_type",b"source_type","url_or_file_path",b"url_or_file_path"]) -> None: ...
global___SetDeviceDbSourceRequest = SetDeviceDbSourceRequest

class ToggleDeviceDbStoreRequest(google.protobuf.message.Message):
    """device_db/toggle_store"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOGGLE_ON_FIELD_NUMBER: builtins.int
    STORE_LOCATION_FIELD_NUMBER: builtins.int
    toggle_on: builtins.bool
    store_location: typing.Text
    def __init__(self,
        *,
        toggle_on: builtins.bool = ...,
        store_location: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["store_location",b"store_location","toggle_on",b"toggle_on"]) -> None: ...
global___ToggleDeviceDbStoreRequest = ToggleDeviceDbStoreRequest

class DeviceDbFailedExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CODE_FIELD_NUMBER: builtins.int
    code: typing.Text
    def __init__(self,
        *,
        code: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code",b"code"]) -> None: ...
global___DeviceDbFailedExceptionData = DeviceDbFailedExceptionData

class OpenInterfaceRequest(google.protobuf.message.Message):
    """---- /interface ----

    interface/open
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_TYPE_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    BAUD_RATE_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    TRANSPORT_FIELD_NUMBER: builtins.int
    REJECT_ROUTED_CONNECTION_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    CONNECTION_NAME_FIELD_NUMBER: builtins.int
    REALM_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    API_FIELD_NUMBER: builtins.int
    interface_type: global___InterfaceType.ValueType
    port_name: typing.Text
    baud_rate: builtins.int
    host_name: typing.Text
    port: builtins.int
    transport: builtins.int
    reject_routed_connection: builtins.bool
    cloud_id: typing.Text
    connection_name: typing.Text
    realm: typing.Text
    token: typing.Text
    api: typing.Text
    def __init__(self,
        *,
        interface_type: global___InterfaceType.ValueType = ...,
        port_name: typing.Text = ...,
        baud_rate: builtins.int = ...,
        host_name: typing.Text = ...,
        port: builtins.int = ...,
        transport: builtins.int = ...,
        reject_routed_connection: builtins.bool = ...,
        cloud_id: typing.Text = ...,
        connection_name: typing.Text = ...,
        realm: typing.Text = ...,
        token: typing.Text = ...,
        api: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["api",b"api","baud_rate",b"baud_rate","cloud_id",b"cloud_id","connection_name",b"connection_name","host_name",b"host_name","interface_type",b"interface_type","port",b"port","port_name",b"port_name","realm",b"realm","reject_routed_connection",b"reject_routed_connection","token",b"token","transport",b"transport"]) -> None: ...
global___OpenInterfaceRequest = OpenInterfaceRequest

class OpenInterfaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_id",b"interface_id"]) -> None: ...
global___OpenInterfaceResponse = OpenInterfaceResponse

class InterfaceEmptyRequest(google.protobuf.message.Message):
    """interface/close
    interface/get_timeout
    interface/get_checksum_enabled
    interface/reset_ids
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_id",b"interface_id"]) -> None: ...
global___InterfaceEmptyRequest = InterfaceEmptyRequest

class SetInterfaceTimeoutRequest(google.protobuf.message.Message):
    """interface/set_timeout"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    timeout: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        timeout: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_id",b"interface_id","timeout",b"timeout"]) -> None: ...
global___SetInterfaceTimeoutRequest = SetInterfaceTimeoutRequest

class SetInterfaceChecksumEnabledRequest(google.protobuf.message.Message):
    """interface/set_checksum_enabled"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    is_enabled: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        is_enabled: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_id",b"interface_id","is_enabled",b"is_enabled"]) -> None: ...
global___SetInterfaceChecksumEnabledRequest = SetInterfaceChecksumEnabledRequest

class AxisEmptyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___AxisEmptyRequest = AxisEmptyRequest

class GenericCommandRequest(google.protobuf.message.Message):
    """interface/generic_command
    interface/generic_command_no_response
    interface/generic_command_multi_response
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CHECK_ERRORS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    command: typing.Text
    check_errors: builtins.bool
    timeout: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        command: typing.Text = ...,
        check_errors: builtins.bool = ...,
        timeout: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","check_errors",b"check_errors","command",b"command","device",b"device","interface_id",b"interface_id","timeout",b"timeout"]) -> None: ...
global___GenericCommandRequest = GenericCommandRequest

class GenericCommandResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    REPLY_FLAG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WARNING_FLAG_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    MESSAGE_TYPE_FIELD_NUMBER: builtins.int
    device_address: builtins.int
    axis_number: builtins.int
    reply_flag: typing.Text
    status: typing.Text
    warning_flag: typing.Text
    data: typing.Text
    message_type: global___MessageType.ValueType
    def __init__(self,
        *,
        device_address: builtins.int = ...,
        axis_number: builtins.int = ...,
        reply_flag: typing.Text = ...,
        status: typing.Text = ...,
        warning_flag: typing.Text = ...,
        data: typing.Text = ...,
        message_type: global___MessageType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","data",b"data","device_address",b"device_address","message_type",b"message_type","reply_flag",b"reply_flag","status",b"status","warning_flag",b"warning_flag"]) -> None: ...
global___GenericCommandResponse = GenericCommandResponse

class GenericCommandResponseCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RESPONSES_FIELD_NUMBER: builtins.int
    @property
    def responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GenericCommandResponse]: ...
    def __init__(self,
        *,
        responses: typing.Optional[typing.Iterable[global___GenericCommandResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["responses",b"responses"]) -> None: ...
global___GenericCommandResponseCollection = GenericCommandResponseCollection

class UnknownResponseEvent(google.protobuf.message.Message):
    """interface/unknown_response"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    REPLY_FLAG_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WARNING_FLAG_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    MESSAGE_TYPE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device_address: builtins.int
    axis_number: builtins.int
    reply_flag: typing.Text
    status: typing.Text
    warning_flag: typing.Text
    data: typing.Text
    message_type: global___MessageType.ValueType
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device_address: builtins.int = ...,
        axis_number: builtins.int = ...,
        reply_flag: typing.Text = ...,
        status: typing.Text = ...,
        warning_flag: typing.Text = ...,
        data: typing.Text = ...,
        message_type: global___MessageType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","data",b"data","device_address",b"device_address","interface_id",b"interface_id","message_type",b"message_type","reply_flag",b"reply_flag","status",b"status","warning_flag",b"warning_flag"]) -> None: ...
global___UnknownResponseEvent = UnknownResponseEvent

class AlertEvent(google.protobuf.message.Message):
    """interface/alert"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WARNING_FLAG_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device_address: builtins.int
    axis_number: builtins.int
    status: typing.Text
    warning_flag: typing.Text
    data: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device_address: builtins.int = ...,
        axis_number: builtins.int = ...,
        status: typing.Text = ...,
        warning_flag: typing.Text = ...,
        data: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","data",b"data","device_address",b"device_address","interface_id",b"interface_id","status",b"status","warning_flag",b"warning_flag"]) -> None: ...
global___AlertEvent = AlertEvent

class DisconnectedEvent(google.protobuf.message.Message):
    """interface/disconnected"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    ERROR_TYPE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    error_type: global___Errors.ValueType
    error_message: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        error_type: global___Errors.ValueType = ...,
        error_message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message",b"error_message","error_type",b"error_type","interface_id",b"interface_id"]) -> None: ...
global___DisconnectedEvent = DisconnectedEvent

class DeviceRenumberRequest(google.protobuf.message.Message):
    """---- /device ----

    device/renumber
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    FIRST_ADDRESS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    first_address: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        first_address: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_address",b"first_address","interface_id",b"interface_id"]) -> None: ...
global___DeviceRenumberRequest = DeviceRenumberRequest

class DeviceDetectRequest(google.protobuf.message.Message):
    """device/detect"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    IDENTIFY_DEVICES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    identify_devices: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        identify_devices: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identify_devices",b"identify_devices","interface_id",b"interface_id"]) -> None: ...
global___DeviceDetectRequest = DeviceDetectRequest

class DeviceDetectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICES_FIELD_NUMBER: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        devices: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["devices",b"devices"]) -> None: ...
global___DeviceDetectResponse = DeviceDetectResponse

class DeviceHomeRequest(google.protobuf.message.Message):
    """device/home"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___DeviceHomeRequest = DeviceHomeRequest

class DeviceWaitUntilIdleRequest(google.protobuf.message.Message):
    """device/wait_until_idle"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    THROW_ERROR_ON_FAULT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    throw_error_on_fault: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        throw_error_on_fault: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
global___DeviceWaitUntilIdleRequest = DeviceWaitUntilIdleRequest

class DeviceMoveRequest(google.protobuf.message.Message):
    """device/move"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _MoveType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _MoveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DeviceMoveRequest._MoveType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: DeviceMoveRequest._MoveType.ValueType  # 0
        REL: DeviceMoveRequest._MoveType.ValueType  # 1
        VEL: DeviceMoveRequest._MoveType.ValueType  # 2
        MAX: DeviceMoveRequest._MoveType.ValueType  # 3
        MIN: DeviceMoveRequest._MoveType.ValueType  # 4
    class MoveType(_MoveType, metaclass=_MoveTypeEnumTypeWrapper):
        pass

    ABS: DeviceMoveRequest.MoveType.ValueType  # 0
    REL: DeviceMoveRequest.MoveType.ValueType  # 1
    VEL: DeviceMoveRequest.MoveType.ValueType  # 2
    MAX: DeviceMoveRequest.MoveType.ValueType  # 3
    MIN: DeviceMoveRequest.MoveType.ValueType  # 4

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ARG_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    VELOCITY_FIELD_NUMBER: builtins.int
    VELOCITY_UNIT_FIELD_NUMBER: builtins.int
    ACCELERATION_FIELD_NUMBER: builtins.int
    ACCELERATION_UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    wait_until_idle: builtins.bool
    type: global___DeviceMoveRequest.MoveType.ValueType
    arg: builtins.float
    unit: typing.Text
    velocity: builtins.float
    velocity_unit: typing.Text
    acceleration: builtins.float
    acceleration_unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        type: global___DeviceMoveRequest.MoveType.ValueType = ...,
        arg: builtins.float = ...,
        unit: typing.Text = ...,
        velocity: builtins.float = ...,
        velocity_unit: typing.Text = ...,
        acceleration: builtins.float = ...,
        acceleration_unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceleration",b"acceleration","acceleration_unit",b"acceleration_unit","arg",b"arg","axis",b"axis","device",b"device","interface_id",b"interface_id","type",b"type","unit",b"unit","velocity",b"velocity","velocity_unit",b"velocity_unit","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___DeviceMoveRequest = DeviceMoveRequest

class DeviceStopRequest(google.protobuf.message.Message):
    """device/stop"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___DeviceStopRequest = DeviceStopRequest

class DeviceOnAllRequest(google.protobuf.message.Message):
    """device/home_all
    device/stop_all
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_id",b"interface_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___DeviceOnAllRequest = DeviceOnAllRequest

class DeviceOnAllResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ADDRESSES_FIELD_NUMBER: builtins.int
    @property
    def device_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        device_addresses: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_addresses",b"device_addresses"]) -> None: ...
global___DeviceOnAllResponse = DeviceOnAllResponse

class DeviceGetWarningsRequest(google.protobuf.message.Message):
    """device/get_warnings"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    CLEAR_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    clear: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        clear: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","clear",b"clear","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceGetWarningsRequest = DeviceGetWarningsRequest

class DeviceGetWarningsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FLAGS_FIELD_NUMBER: builtins.int
    @property
    def flags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        flags: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["flags",b"flags"]) -> None: ...
global___DeviceGetWarningsResponse = DeviceGetWarningsResponse

class DeviceGetAllDigitalIORequest(google.protobuf.message.Message):
    """device/get_all_digital_io"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_type: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_type",b"channel_type","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceGetAllDigitalIORequest = DeviceGetAllDigitalIORequest

class DeviceGetAllDigitalIOResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    def __init__(self,
        *,
        values: typing.Optional[typing.Iterable[builtins.bool]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values",b"values"]) -> None: ...
global___DeviceGetAllDigitalIOResponse = DeviceGetAllDigitalIOResponse

class DeviceGetAllAnalogIORequest(google.protobuf.message.Message):
    """device/get_all_analog_io"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_type: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_type",b"channel_type","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceGetAllAnalogIORequest = DeviceGetAllAnalogIORequest

class DeviceGetAllAnalogIOResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        values: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values",b"values"]) -> None: ...
global___DeviceGetAllAnalogIOResponse = DeviceGetAllAnalogIOResponse

class DeviceGetDigitalIORequest(google.protobuf.message.Message):
    """device/get_digital_io"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_type: typing.Text
    channel_number: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_type: typing.Text = ...,
        channel_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","channel_type",b"channel_type","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceGetDigitalIORequest = DeviceGetDigitalIORequest

class DeviceGetAnalogIORequest(google.protobuf.message.Message):
    """device/get_analog_io"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_type: typing.Text
    channel_number: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_type: typing.Text = ...,
        channel_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","channel_type",b"channel_type","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceGetAnalogIORequest = DeviceGetAnalogIORequest

class DeviceSetAllDigitalOutputsRequest(google.protobuf.message.Message):
    """device/set_all_digital_outputs"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        values: typing.Optional[typing.Iterable[builtins.bool]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","values",b"values"]) -> None: ...
global___DeviceSetAllDigitalOutputsRequest = DeviceSetAllDigitalOutputsRequest

class DeviceSetAllAnalogOutputsRequest(google.protobuf.message.Message):
    """device/set_all_analog_outputs"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        values: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","values",b"values"]) -> None: ...
global___DeviceSetAllAnalogOutputsRequest = DeviceSetAllAnalogOutputsRequest

class DeviceSetDigitalOutputRequest(google.protobuf.message.Message):
    """device/set_digital_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_number: builtins.int
    value: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_number: builtins.int = ...,
        value: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","value",b"value"]) -> None: ...
global___DeviceSetDigitalOutputRequest = DeviceSetDigitalOutputRequest

class DeviceSetAnalogOutputRequest(google.protobuf.message.Message):
    """device/set_analog_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    channel_number: builtins.int
    value: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        channel_number: builtins.int = ...,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","value",b"value"]) -> None: ...
global___DeviceSetAnalogOutputRequest = DeviceSetAnalogOutputRequest

class SetLogOutputRequest(google.protobuf.message.Message):
    """loging/set_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MODE_FIELD_NUMBER: builtins.int
    FILE_PATH_FIELD_NUMBER: builtins.int
    mode: builtins.int
    file_path: typing.Text
    def __init__(self,
        *,
        mode: builtins.int = ...,
        file_path: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_path",b"file_path","mode",b"mode"]) -> None: ...
global___SetLogOutputRequest = SetLogOutputRequest

class DeviceGetSettingRequest(google.protobuf.message.Message):
    """device/get_axis_setting
    device/get_axis_setting_str
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    setting: typing.Text
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        setting: typing.Text = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","setting",b"setting","unit",b"unit"]) -> None: ...
global___DeviceGetSettingRequest = DeviceGetSettingRequest

class DeviceConvertSettingRequest(google.protobuf.message.Message):
    """device/convert_axis_setting"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    FROM_NATIVE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    setting: typing.Text
    unit: typing.Text
    value: builtins.float
    from_native: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        setting: typing.Text = ...,
        unit: typing.Text = ...,
        value: builtins.float = ...,
        from_native: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","from_native",b"from_native","interface_id",b"interface_id","setting",b"setting","unit",b"unit","value",b"value"]) -> None: ...
global___DeviceConvertSettingRequest = DeviceConvertSettingRequest

class DeviceSetSettingRequest(google.protobuf.message.Message):
    """device/set_setting"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    setting: typing.Text
    value: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        setting: typing.Text = ...,
        value: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","setting",b"setting","unit",b"unit","value",b"value"]) -> None: ...
global___DeviceSetSettingRequest = DeviceSetSettingRequest

class DeviceSetSettingStrRequest(google.protobuf.message.Message):
    """device/set_setting_str"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    setting: typing.Text
    value: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        setting: typing.Text = ...,
        value: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","setting",b"setting","value",b"value"]) -> None: ...
global___DeviceSetSettingStrRequest = DeviceSetSettingStrRequest

class PrepareCommandRequest(google.protobuf.message.Message):
    """device/prepare_command"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    COMMAND_TEMPLATE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    command_template: typing.Text
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Measurement]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        command_template: typing.Text = ...,
        parameters: typing.Optional[typing.Iterable[global___Measurement]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","command_template",b"command_template","device",b"device","interface_id",b"interface_id","parameters",b"parameters"]) -> None: ...
global___PrepareCommandRequest = PrepareCommandRequest

class LockstepEnableRequest(google.protobuf.message.Message):
    """---- /device lockstep ----

    device/lockstep_enable
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id"]) -> None: ...
global___LockstepEnableRequest = LockstepEnableRequest

class LockstepDisableRequest(google.protobuf.message.Message):
    """device/lockstep_disable"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___LockstepDisableRequest = LockstepDisableRequest

class LockstepStopRequest(google.protobuf.message.Message):
    """device/lockstep_stop"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___LockstepStopRequest = LockstepStopRequest

class LockstepHomeRequest(google.protobuf.message.Message):
    """device/lockstep_home"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___LockstepHomeRequest = LockstepHomeRequest

class LockstepMoveRequest(google.protobuf.message.Message):
    """device/lockstep_move"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _MoveType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _MoveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LockstepMoveRequest._MoveType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: LockstepMoveRequest._MoveType.ValueType  # 0
        REL: LockstepMoveRequest._MoveType.ValueType  # 1
        VEL: LockstepMoveRequest._MoveType.ValueType  # 2
        MAX: LockstepMoveRequest._MoveType.ValueType  # 3
        MIN: LockstepMoveRequest._MoveType.ValueType  # 4
    class MoveType(_MoveType, metaclass=_MoveTypeEnumTypeWrapper):
        pass

    ABS: LockstepMoveRequest.MoveType.ValueType  # 0
    REL: LockstepMoveRequest.MoveType.ValueType  # 1
    VEL: LockstepMoveRequest.MoveType.ValueType  # 2
    MAX: LockstepMoveRequest.MoveType.ValueType  # 3
    MIN: LockstepMoveRequest.MoveType.ValueType  # 4

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ARG_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    VELOCITY_FIELD_NUMBER: builtins.int
    VELOCITY_UNIT_FIELD_NUMBER: builtins.int
    ACCELERATION_FIELD_NUMBER: builtins.int
    ACCELERATION_UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    wait_until_idle: builtins.bool
    type: global___LockstepMoveRequest.MoveType.ValueType
    arg: builtins.float
    unit: typing.Text
    velocity: builtins.float
    velocity_unit: typing.Text
    acceleration: builtins.float
    acceleration_unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        type: global___LockstepMoveRequest.MoveType.ValueType = ...,
        arg: builtins.float = ...,
        unit: typing.Text = ...,
        velocity: builtins.float = ...,
        velocity_unit: typing.Text = ...,
        acceleration: builtins.float = ...,
        acceleration_unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["acceleration",b"acceleration","acceleration_unit",b"acceleration_unit","arg",b"arg","device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","type",b"type","unit",b"unit","velocity",b"velocity","velocity_unit",b"velocity_unit","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___LockstepMoveRequest = LockstepMoveRequest

class LockstepWaitUntilIdleRequest(google.protobuf.message.Message):
    """device/lockstep_wait_until_idle"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    THROW_ERROR_ON_FAULT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    throw_error_on_fault: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        throw_error_on_fault: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
global___LockstepWaitUntilIdleRequest = LockstepWaitUntilIdleRequest

class LockstepEmptyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id"]) -> None: ...
global___LockstepEmptyRequest = LockstepEmptyRequest

class LockstepAxes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_1_FIELD_NUMBER: builtins.int
    AXIS_2_FIELD_NUMBER: builtins.int
    AXIS_3_FIELD_NUMBER: builtins.int
    AXIS_4_FIELD_NUMBER: builtins.int
    axis_1: builtins.int
    axis_2: builtins.int
    axis_3: builtins.int
    axis_4: builtins.int
    def __init__(self,
        *,
        axis_1: builtins.int = ...,
        axis_2: builtins.int = ...,
        axis_3: builtins.int = ...,
        axis_4: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_1",b"axis_1","axis_2",b"axis_2","axis_3",b"axis_3","axis_4",b"axis_4"]) -> None: ...
global___LockstepAxes = LockstepAxes

class LockstepGetAxisNumbersResponse(google.protobuf.message.Message):
    """device/lockstep_get_axis_numbers"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXES_FIELD_NUMBER: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        axes: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes"]) -> None: ...
global___LockstepGetAxisNumbersResponse = LockstepGetAxisNumbersResponse

class LockstepGetTwistsRequest(google.protobuf.message.Message):
    """device/lockstep_get_twists"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","unit",b"unit"]) -> None: ...
global___LockstepGetTwistsRequest = LockstepGetTwistsRequest

class LockstepGetTwistsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TWISTS_FIELD_NUMBER: builtins.int
    @property
    def twists(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        twists: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["twists",b"twists"]) -> None: ...
global___LockstepGetTwistsResponse = LockstepGetTwistsResponse

class LockstepGetOffsetsRequest(google.protobuf.message.Message):
    """device/lockstep_get_offsets"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    LOCKSTEP_GROUP_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    lockstep_group_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        lockstep_group_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","lockstep_group_id",b"lockstep_group_id","unit",b"unit"]) -> None: ...
global___LockstepGetOffsetsRequest = LockstepGetOffsetsRequest

class LockstepGetOffsetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OFFSETS_FIELD_NUMBER: builtins.int
    @property
    def offsets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        offsets: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["offsets",b"offsets"]) -> None: ...
global___LockstepGetOffsetsResponse = LockstepGetOffsetsResponse

class OscilloscopeAddChannelRequest(google.protobuf.message.Message):
    """---- /device oscilloscope ----

    oscilloscope/add_channel
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    setting: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        setting: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","setting",b"setting"]) -> None: ...
global___OscilloscopeAddChannelRequest = OscilloscopeAddChannelRequest

class OscilloscopeStartStopRequest(google.protobuf.message.Message):
    """oscilloscope/start_or_stop"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    start: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        start: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","start",b"start"]) -> None: ...
global___OscilloscopeStartStopRequest = OscilloscopeStartStopRequest

class OscilloscopeReadResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_IDS_FIELD_NUMBER: builtins.int
    @property
    def data_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        data_ids: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_ids",b"data_ids"]) -> None: ...
global___OscilloscopeReadResponse = OscilloscopeReadResponse

class OscilloscopeDataIdentifier(google.protobuf.message.Message):
    """oscilloscopedata/get_properties
    oscilloscopedata/get_samples
    oscilloscopedata/free
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_ID_FIELD_NUMBER: builtins.int
    data_id: builtins.int
    def __init__(self,
        *,
        data_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_id",b"data_id"]) -> None: ...
global___OscilloscopeDataIdentifier = OscilloscopeDataIdentifier

class OscilloscopeCaptureProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SETTING_FIELD_NUMBER: builtins.int
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    setting: typing.Text
    axis_number: builtins.int
    def __init__(self,
        *,
        setting: typing.Text = ...,
        axis_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","setting",b"setting"]) -> None: ...
global___OscilloscopeCaptureProperties = OscilloscopeCaptureProperties

class OscilloscopeDataGetRequest(google.protobuf.message.Message):
    """oscilloscopedata/get_timebase
    oscilloscopedata/get_delay
    oscilloscopedata/get_samples
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    data_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        data_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_id",b"data_id","unit",b"unit"]) -> None: ...
global___OscilloscopeDataGetRequest = OscilloscopeDataGetRequest

class OscilloscopeDataGetSampleTimeRequest(google.protobuf.message.Message):
    """oscilloscopedata/get_sample_time"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    data_id: builtins.int
    unit: typing.Text
    index: builtins.int
    def __init__(self,
        *,
        data_id: builtins.int = ...,
        unit: typing.Text = ...,
        index: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_id",b"data_id","index",b"index","unit",b"unit"]) -> None: ...
global___OscilloscopeDataGetSampleTimeRequest = OscilloscopeDataGetSampleTimeRequest

class OscilloscopeDataGetSamplesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        data: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data",b"data"]) -> None: ...
global___OscilloscopeDataGetSamplesResponse = OscilloscopeDataGetSamplesResponse

class StreamSetupLiveRequest(google.protobuf.message.Message):
    """---- /device streams ----

    device/stream_setup_live
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamSetupLiveRequest = StreamSetupLiveRequest

class StreamSetupLiveCompositeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamAxisDefinition]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[global___StreamAxisDefinition]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamSetupLiveCompositeRequest = StreamSetupLiveCompositeRequest

class StreamSetupStoreRequest(google.protobuf.message.Message):
    """device/stream_setup_store"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    STREAM_BUFFER_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    stream_buffer: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        stream_buffer: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device",b"device","interface_id",b"interface_id","stream_buffer",b"stream_buffer","stream_id",b"stream_id"]) -> None: ...
global___StreamSetupStoreRequest = StreamSetupStoreRequest

class StreamSetupStoreCompositeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    STREAM_BUFFER_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    stream_buffer: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamAxisDefinition]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        stream_buffer: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[global___StreamAxisDefinition]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device",b"device","interface_id",b"interface_id","stream_buffer",b"stream_buffer","stream_id",b"stream_id"]) -> None: ...
global___StreamSetupStoreCompositeRequest = StreamSetupStoreCompositeRequest

class StreamSetupStoreArbitraryAxesRequest(google.protobuf.message.Message):
    """device/stream_enable_store_arbitrary_axes"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    STREAM_BUFFER_FIELD_NUMBER: builtins.int
    AXES_COUNT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    stream_buffer: builtins.int
    axes_count: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        stream_buffer: builtins.int = ...,
        axes_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes_count",b"axes_count","device",b"device","interface_id",b"interface_id","stream_buffer",b"stream_buffer","stream_id",b"stream_id"]) -> None: ...
global___StreamSetupStoreArbitraryAxesRequest = StreamSetupStoreArbitraryAxesRequest

class StreamCallRequest(google.protobuf.message.Message):
    """device/stream_call"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    STREAM_BUFFER_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    stream_buffer: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        stream_buffer: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_buffer",b"stream_buffer","stream_id",b"stream_id"]) -> None: ...
global___StreamCallRequest = StreamCallRequest

class StreamLineRequest(google.protobuf.message.Message):
    """device/stream_line"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Type:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamLineRequest._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: StreamLineRequest._Type.ValueType  # 0
        REL: StreamLineRequest._Type.ValueType  # 1
    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        pass

    ABS: StreamLineRequest.Type.ValueType  # 0
    REL: StreamLineRequest.Type.ValueType  # 1

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    TARGET_AXES_INDICES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    type: global___StreamLineRequest.Type.ValueType
    @property
    def endpoint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Measurement]: ...
    @property
    def target_axes_indices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        type: global___StreamLineRequest.Type.ValueType = ...,
        endpoint: typing.Optional[typing.Iterable[global___Measurement]] = ...,
        target_axes_indices: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","endpoint",b"endpoint","interface_id",b"interface_id","stream_id",b"stream_id","target_axes_indices",b"target_axes_indices","type",b"type"]) -> None: ...
global___StreamLineRequest = StreamLineRequest

class StreamArcRequest(google.protobuf.message.Message):
    """device/stream_arc"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Type:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamArcRequest._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: StreamArcRequest._Type.ValueType  # 0
        REL: StreamArcRequest._Type.ValueType  # 1
    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        pass

    ABS: StreamArcRequest.Type.ValueType  # 0
    REL: StreamArcRequest.Type.ValueType  # 1

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROTATION_DIRECTION_FIELD_NUMBER: builtins.int
    CENTER_X_FIELD_NUMBER: builtins.int
    CENTER_Y_FIELD_NUMBER: builtins.int
    END_X_FIELD_NUMBER: builtins.int
    END_Y_FIELD_NUMBER: builtins.int
    TARGET_AXES_INDICES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    type: global___StreamArcRequest.Type.ValueType
    rotation_direction: builtins.int
    @property
    def center_x(self) -> global___Measurement: ...
    @property
    def center_y(self) -> global___Measurement: ...
    @property
    def end_x(self) -> global___Measurement: ...
    @property
    def end_y(self) -> global___Measurement: ...
    @property
    def target_axes_indices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        type: global___StreamArcRequest.Type.ValueType = ...,
        rotation_direction: builtins.int = ...,
        center_x: typing.Optional[global___Measurement] = ...,
        center_y: typing.Optional[global___Measurement] = ...,
        end_x: typing.Optional[global___Measurement] = ...,
        end_y: typing.Optional[global___Measurement] = ...,
        target_axes_indices: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["center_x",b"center_x","center_y",b"center_y","end_x",b"end_x","end_y",b"end_y"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["center_x",b"center_x","center_y",b"center_y","device",b"device","end_x",b"end_x","end_y",b"end_y","interface_id",b"interface_id","rotation_direction",b"rotation_direction","stream_id",b"stream_id","target_axes_indices",b"target_axes_indices","type",b"type"]) -> None: ...
global___StreamArcRequest = StreamArcRequest

class StreamCircleRequest(google.protobuf.message.Message):
    """device/stream_circle"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _Type:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamCircleRequest._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: StreamCircleRequest._Type.ValueType  # 0
        REL: StreamCircleRequest._Type.ValueType  # 1
    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        pass

    ABS: StreamCircleRequest.Type.ValueType  # 0
    REL: StreamCircleRequest.Type.ValueType  # 1

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROTATION_DIRECTION_FIELD_NUMBER: builtins.int
    CENTER_X_FIELD_NUMBER: builtins.int
    CENTER_Y_FIELD_NUMBER: builtins.int
    TARGET_AXES_INDICES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    type: global___StreamCircleRequest.Type.ValueType
    rotation_direction: builtins.int
    @property
    def center_x(self) -> global___Measurement: ...
    @property
    def center_y(self) -> global___Measurement: ...
    @property
    def target_axes_indices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        type: global___StreamCircleRequest.Type.ValueType = ...,
        rotation_direction: builtins.int = ...,
        center_x: typing.Optional[global___Measurement] = ...,
        center_y: typing.Optional[global___Measurement] = ...,
        target_axes_indices: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["center_x",b"center_x","center_y",b"center_y"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["center_x",b"center_x","center_y",b"center_y","device",b"device","interface_id",b"interface_id","rotation_direction",b"rotation_direction","stream_id",b"stream_id","target_axes_indices",b"target_axes_indices","type",b"type"]) -> None: ...
global___StreamCircleRequest = StreamCircleRequest

class StreamWaitDigitalInputRequest(google.protobuf.message.Message):
    """device/stream_wait_digital_input"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    channel_number: builtins.int
    value: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        channel_number: builtins.int = ...,
        value: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","value",b"value"]) -> None: ...
global___StreamWaitDigitalInputRequest = StreamWaitDigitalInputRequest

class StreamWaitAnalogInputRequest(google.protobuf.message.Message):
    """device/stream_wait_analog_input"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    channel_number: builtins.int
    condition: typing.Text
    value: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        channel_number: builtins.int = ...,
        condition: typing.Text = ...,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","condition",b"condition","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","value",b"value"]) -> None: ...
global___StreamWaitAnalogInputRequest = StreamWaitAnalogInputRequest

class StreamSetDigitalOutputRequest(google.protobuf.message.Message):
    """device/stream_set_digital_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    channel_number: builtins.int
    value: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        channel_number: builtins.int = ...,
        value: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","value",b"value"]) -> None: ...
global___StreamSetDigitalOutputRequest = StreamSetDigitalOutputRequest

class StreamSetAnalogOutputRequest(google.protobuf.message.Message):
    """device/stream_set_analog_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    channel_number: builtins.int
    value: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        channel_number: builtins.int = ...,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","value",b"value"]) -> None: ...
global___StreamSetAnalogOutputRequest = StreamSetAnalogOutputRequest

class StreamToggleDigitalOutputRequest(google.protobuf.message.Message):
    """device/stream_toggle_digital_output"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CHANNEL_NUMBER_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    channel_number: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        channel_number: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["channel_number",b"channel_number","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamToggleDigitalOutputRequest = StreamToggleDigitalOutputRequest

class StreamSetAllDigitalOutputsRequest(google.protobuf.message.Message):
    """device/stream_set_all_digital_outputs"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        values: typing.Optional[typing.Iterable[builtins.bool]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","values",b"values"]) -> None: ...
global___StreamSetAllDigitalOutputsRequest = StreamSetAllDigitalOutputsRequest

class StreamSetAllAnalogOutputsRequest(google.protobuf.message.Message):
    """device/stream_set_all_analog_outputs"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        values: typing.Optional[typing.Iterable[builtins.float]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","values",b"values"]) -> None: ...
global___StreamSetAllAnalogOutputsRequest = StreamSetAllAnalogOutputsRequest

class StreamWaitRequest(google.protobuf.message.Message):
    """device/stream_wait"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    time: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        time: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","time",b"time","unit",b"unit"]) -> None: ...
global___StreamWaitRequest = StreamWaitRequest

class StreamWaitUntilIdleRequest(google.protobuf.message.Message):
    """device/stream_wait_until_idle"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    THROW_ERROR_ON_FAULT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    throw_error_on_fault: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        throw_error_on_fault: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","throw_error_on_fault",b"throw_error_on_fault"]) -> None: ...
global___StreamWaitUntilIdleRequest = StreamWaitUntilIdleRequest

class StreamEmptyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamEmptyRequest = StreamEmptyRequest

class StreamGetAxesResponse(google.protobuf.message.Message):
    """device/stream_get_axes"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXES_FIELD_NUMBER: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StreamAxisDefinition]: ...
    def __init__(self,
        *,
        axes: typing.Optional[typing.Iterable[global___StreamAxisDefinition]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes"]) -> None: ...
global___StreamGetAxesResponse = StreamGetAxesResponse

class StreamGetMaxSpeedRequest(google.protobuf.message.Message):
    """device/stream_get_max_speed"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamGetMaxSpeedRequest = StreamGetMaxSpeedRequest

class StreamSetMaxSpeedRequest(google.protobuf.message.Message):
    """device/stream_set_max_speed"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    MAX_SPEED_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    max_speed: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        max_speed: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","max_speed",b"max_speed","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamSetMaxSpeedRequest = StreamSetMaxSpeedRequest

class StreamGetMaxTangentialAccelerationRequest(google.protobuf.message.Message):
    """device/stream_get_max_tangential_acceleration"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamGetMaxTangentialAccelerationRequest = StreamGetMaxTangentialAccelerationRequest

class StreamSetMaxTangentialAccelerationRequest(google.protobuf.message.Message):
    """device/stream_set_max_tangential_acceleration"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    MAX_TANGENTIAL_ACCELERATION_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    max_tangential_acceleration: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        max_tangential_acceleration: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","max_tangential_acceleration",b"max_tangential_acceleration","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamSetMaxTangentialAccelerationRequest = StreamSetMaxTangentialAccelerationRequest

class StreamGetMaxCentripetalAccelerationRequest(google.protobuf.message.Message):
    """device/stream_get_max_centripetal_acceleration"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamGetMaxCentripetalAccelerationRequest = StreamGetMaxCentripetalAccelerationRequest

class StreamSetMaxCentripetalAccelerationRequest(google.protobuf.message.Message):
    """device/stream_set_max_centripetal_acceleration"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    MAX_CENTRIPETAL_ACCELERATION_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    max_centripetal_acceleration: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        max_centripetal_acceleration: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","max_centripetal_acceleration",b"max_centripetal_acceleration","stream_id",b"stream_id","unit",b"unit"]) -> None: ...
global___StreamSetMaxCentripetalAccelerationRequest = StreamSetMaxCentripetalAccelerationRequest

class StreamBufferGetContentRequest(google.protobuf.message.Message):
    """device/stream_buffer_get_content"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUFFER_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    buffer_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        buffer_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffer_id",b"buffer_id","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___StreamBufferGetContentRequest = StreamBufferGetContentRequest

class StreamBufferGetContentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BUFFER_LINES_FIELD_NUMBER: builtins.int
    @property
    def buffer_lines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        buffer_lines: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffer_lines",b"buffer_lines"]) -> None: ...
global___StreamBufferGetContentResponse = StreamBufferGetContentResponse

class StreamBufferEraseRequest(google.protobuf.message.Message):
    """device/stream_buffer_erase"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    BUFFER_ID_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    buffer_id: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        buffer_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buffer_id",b"buffer_id","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___StreamBufferEraseRequest = StreamBufferEraseRequest

class StreamGenericCommandRequest(google.protobuf.message.Message):
    """device/stream_generic_command"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    command: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        command: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamGenericCommandRequest = StreamGenericCommandRequest

class StreamGenericCommandBatchRequest(google.protobuf.message.Message):
    """device/stream_generic_command_batch"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    BATCH_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def batch(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        batch: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch",b"batch","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___StreamGenericCommandBatchRequest = StreamGenericCommandBatchRequest

class BinaryReplyOnlyEvent(google.protobuf.message.Message):
    """---- binary/interface ----

    binary/interface/reply_only
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device_address: builtins.int
    command: builtins.int
    data: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device_address: builtins.int = ...,
        command: builtins.int = ...,
        data: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","data",b"data","device_address",b"device_address","interface_id",b"interface_id"]) -> None: ...
global___BinaryReplyOnlyEvent = BinaryReplyOnlyEvent

class OpenBinaryInterfaceRequest(google.protobuf.message.Message):
    """binary/interface/open"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_TYPE_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    BAUD_RATE_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    USE_MESSAGE_IDS_FIELD_NUMBER: builtins.int
    interface_type: global___InterfaceType.ValueType
    port_name: typing.Text
    baud_rate: builtins.int
    host_name: typing.Text
    port: builtins.int
    use_message_ids: builtins.bool
    def __init__(self,
        *,
        interface_type: global___InterfaceType.ValueType = ...,
        port_name: typing.Text = ...,
        baud_rate: builtins.int = ...,
        host_name: typing.Text = ...,
        port: builtins.int = ...,
        use_message_ids: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["baud_rate",b"baud_rate","host_name",b"host_name","interface_type",b"interface_type","port",b"port","port_name",b"port_name","use_message_ids",b"use_message_ids"]) -> None: ...
global___OpenBinaryInterfaceRequest = OpenBinaryInterfaceRequest

class UnknownBinaryResponseEvent(google.protobuf.message.Message):
    """binary/interface/unknown_response"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device_address: builtins.int
    command: builtins.int
    data: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device_address: builtins.int = ...,
        command: builtins.int = ...,
        data: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","data",b"data","device_address",b"device_address","interface_id",b"interface_id"]) -> None: ...
global___UnknownBinaryResponseEvent = UnknownBinaryResponseEvent

class GenericBinaryRequest(google.protobuf.message.Message):
    """binary/interface/generic_command
    binary/interface/generic_command_no_response
    binary/interface/generic_command_multi_response
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    CHECK_ERRORS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    command: builtins.int
    data: builtins.int
    check_errors: builtins.bool
    timeout: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        command: builtins.int = ...,
        data: builtins.int = ...,
        check_errors: builtins.bool = ...,
        timeout: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_errors",b"check_errors","command",b"command","data",b"data","device",b"device","interface_id",b"interface_id","timeout",b"timeout"]) -> None: ...
global___GenericBinaryRequest = GenericBinaryRequest

class BinaryMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ADDRESS_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    device_address: builtins.int
    command: builtins.int
    data: builtins.int
    def __init__(self,
        *,
        device_address: builtins.int = ...,
        command: builtins.int = ...,
        data: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","data",b"data","device_address",b"device_address"]) -> None: ...
global___BinaryMessage = BinaryMessage

class BinaryMessageCollection(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGES_FIELD_NUMBER: builtins.int
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BinaryMessage]: ...
    def __init__(self,
        *,
        messages: typing.Optional[typing.Iterable[global___BinaryMessage]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["messages",b"messages"]) -> None: ...
global___BinaryMessageCollection = BinaryMessageCollection

class DeviceEmptyRequest(google.protobuf.message.Message):
    """---- binary/device ----

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id"]) -> None: ...
global___DeviceEmptyRequest = DeviceEmptyRequest

class BinaryDeviceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _DeviceType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _DeviceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BinaryDeviceIdentity._DeviceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: BinaryDeviceIdentity._DeviceType.ValueType  # 0
        LINEAR: BinaryDeviceIdentity._DeviceType.ValueType  # 1
        ROTARY: BinaryDeviceIdentity._DeviceType.ValueType  # 2
    class DeviceType(_DeviceType, metaclass=_DeviceTypeEnumTypeWrapper):
        pass

    UNKNOWN: BinaryDeviceIdentity.DeviceType.ValueType  # 0
    LINEAR: BinaryDeviceIdentity.DeviceType.ValueType  # 1
    ROTARY: BinaryDeviceIdentity.DeviceType.ValueType  # 2

    DEVICE_ID_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FIRMWARE_VERSION_FIELD_NUMBER: builtins.int
    IS_PERIPHERAL_FIELD_NUMBER: builtins.int
    PERIPHERAL_ID_FIELD_NUMBER: builtins.int
    PERIPHERAL_NAME_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    device_id: builtins.int
    serial_number: builtins.int
    name: typing.Text
    @property
    def firmware_version(self) -> global___FirmwareVersion: ...
    is_peripheral: builtins.bool
    peripheral_id: builtins.int
    peripheral_name: typing.Text
    device_type: global___BinaryDeviceIdentity.DeviceType.ValueType
    def __init__(self,
        *,
        device_id: builtins.int = ...,
        serial_number: builtins.int = ...,
        name: typing.Text = ...,
        firmware_version: typing.Optional[global___FirmwareVersion] = ...,
        is_peripheral: builtins.bool = ...,
        peripheral_id: builtins.int = ...,
        peripheral_name: typing.Text = ...,
        device_type: global___BinaryDeviceIdentity.DeviceType.ValueType = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["firmware_version",b"firmware_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_id",b"device_id","device_type",b"device_type","firmware_version",b"firmware_version","is_peripheral",b"is_peripheral","name",b"name","peripheral_id",b"peripheral_id","peripheral_name",b"peripheral_name","serial_number",b"serial_number"]) -> None: ...
global___BinaryDeviceIdentity = BinaryDeviceIdentity

class BinaryGenericWithUnitsRequest(google.protobuf.message.Message):
    """binary/device/generic_command_with_units"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    FROM_UNIT_FIELD_NUMBER: builtins.int
    TO_UNIT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    command: builtins.int
    data: builtins.float
    from_unit: typing.Text
    to_unit: typing.Text
    timeout: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        command: builtins.int = ...,
        data: builtins.float = ...,
        from_unit: typing.Text = ...,
        to_unit: typing.Text = ...,
        timeout: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command",b"command","data",b"data","device",b"device","from_unit",b"from_unit","interface_id",b"interface_id","timeout",b"timeout","to_unit",b"to_unit"]) -> None: ...
global___BinaryGenericWithUnitsRequest = BinaryGenericWithUnitsRequest

class BinaryDeviceHomeRequest(google.protobuf.message.Message):
    """binary/device/home"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    timeout: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        timeout: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","timeout",b"timeout","unit",b"unit"]) -> None: ...
global___BinaryDeviceHomeRequest = BinaryDeviceHomeRequest

class BinaryDeviceMoveRequest(google.protobuf.message.Message):
    """binary/device/move"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class _MoveType:
        ValueType = typing.NewType('ValueType', builtins.int)
        V: typing_extensions.TypeAlias = ValueType
    class _MoveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BinaryDeviceMoveRequest._MoveType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ABS: BinaryDeviceMoveRequest._MoveType.ValueType  # 0
        REL: BinaryDeviceMoveRequest._MoveType.ValueType  # 1
        VEL: BinaryDeviceMoveRequest._MoveType.ValueType  # 2
    class MoveType(_MoveType, metaclass=_MoveTypeEnumTypeWrapper):
        pass

    ABS: BinaryDeviceMoveRequest.MoveType.ValueType  # 0
    REL: BinaryDeviceMoveRequest.MoveType.ValueType  # 1
    VEL: BinaryDeviceMoveRequest.MoveType.ValueType  # 2

    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ARG_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    timeout: builtins.float
    type: global___BinaryDeviceMoveRequest.MoveType.ValueType
    arg: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        timeout: builtins.float = ...,
        type: global___BinaryDeviceMoveRequest.MoveType.ValueType = ...,
        arg: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arg",b"arg","device",b"device","interface_id",b"interface_id","timeout",b"timeout","type",b"type","unit",b"unit"]) -> None: ...
global___BinaryDeviceMoveRequest = BinaryDeviceMoveRequest

class BinaryDeviceStopRequest(google.protobuf.message.Message):
    """binary/device/stop"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    timeout: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        timeout: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","timeout",b"timeout","unit",b"unit"]) -> None: ...
global___BinaryDeviceStopRequest = BinaryDeviceStopRequest

class BinaryDeviceDetectRequest(google.protobuf.message.Message):
    """binary/device/detect"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    IDENTIFY_DEVICES_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    identify_devices: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        identify_devices: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identify_devices",b"identify_devices","interface_id",b"interface_id"]) -> None: ...
global___BinaryDeviceDetectRequest = BinaryDeviceDetectRequest

class BinaryDeviceDetectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICES_FIELD_NUMBER: builtins.int
    @property
    def devices(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(self,
        *,
        devices: typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["devices",b"devices"]) -> None: ...
global___BinaryDeviceDetectResponse = BinaryDeviceDetectResponse

class BinaryDeviceGetSettingRequest(google.protobuf.message.Message):
    """binary/device/get_setting"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    setting: builtins.int
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        setting: builtins.int = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","setting",b"setting","unit",b"unit"]) -> None: ...
global___BinaryDeviceGetSettingRequest = BinaryDeviceGetSettingRequest

class BinaryDeviceSetSettingRequest(google.protobuf.message.Message):
    """binary/device/set_setting"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    SETTING_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    setting: builtins.int
    value: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        setting: builtins.int = ...,
        value: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device",b"device","interface_id",b"interface_id","setting",b"setting","unit",b"unit","value",b"value"]) -> None: ...
global___BinaryDeviceSetSettingRequest = BinaryDeviceSetSettingRequest

class CustomInterfaceReadRequest(google.protobuf.message.Message):
    """---- custom/interface ----

    custom/interface/read
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSPORT_ID_FIELD_NUMBER: builtins.int
    transport_id: builtins.int
    def __init__(self,
        *,
        transport_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["transport_id",b"transport_id"]) -> None: ...
global___CustomInterfaceReadRequest = CustomInterfaceReadRequest

class CustomInterfaceWriteRequest(google.protobuf.message.Message):
    """custom/interface/write"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSPORT_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    transport_id: builtins.int
    message: typing.Text
    def __init__(self,
        *,
        transport_id: builtins.int = ...,
        message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message",b"message","transport_id",b"transport_id"]) -> None: ...
global___CustomInterfaceWriteRequest = CustomInterfaceWriteRequest

class CustomInterfaceOpenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSPORT_ID_FIELD_NUMBER: builtins.int
    transport_id: builtins.int
    def __init__(self,
        *,
        transport_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["transport_id",b"transport_id"]) -> None: ...
global___CustomInterfaceOpenResponse = CustomInterfaceOpenResponse

class CustomInterfaceCloseRequest(google.protobuf.message.Message):
    """custom/interface/close"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSPORT_ID_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    transport_id: builtins.int
    error_message: typing.Text
    def __init__(self,
        *,
        transport_id: builtins.int = ...,
        error_message: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_message",b"error_message","transport_id",b"transport_id"]) -> None: ...
global___CustomInterfaceCloseRequest = CustomInterfaceCloseRequest

class CanSetStateRequest(google.protobuf.message.Message):
    """device/can_set_state"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    state: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        state: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","state",b"state"]) -> None: ...
global___CanSetStateRequest = CanSetStateRequest

class CanSetStateAxisResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_NUMBER_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    axis_number: builtins.int
    error: typing.Text
    def __init__(self,
        *,
        axis_number: builtins.int = ...,
        error: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_number",b"axis_number","error",b"error"]) -> None: ...
global___CanSetStateAxisResponse = CanSetStateAxisResponse

class CanSetStateDeviceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ERROR_FIELD_NUMBER: builtins.int
    AXIS_ERRORS_FIELD_NUMBER: builtins.int
    error: typing.Text
    @property
    def axis_errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CanSetStateAxisResponse]: ...
    def __init__(self,
        *,
        error: typing.Text = ...,
        axis_errors: typing.Optional[typing.Iterable[global___CanSetStateAxisResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_errors",b"axis_errors","error",b"error"]) -> None: ...
global___CanSetStateDeviceResponse = CanSetStateDeviceResponse

class SetStateRequest(google.protobuf.message.Message):
    """device/set_state"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    DEVICE_ONLY_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    state: typing.Text
    device_only: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        state: typing.Text = ...,
        device_only: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","device_only",b"device_only","interface_id",b"interface_id","state",b"state"]) -> None: ...
global___SetStateRequest = SetStateRequest

class ServoTuningRequest(google.protobuf.message.Message):
    """servotuning basic request"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    PARAMSET_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    paramset: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        paramset: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","paramset",b"paramset"]) -> None: ...
global___ServoTuningRequest = ServoTuningRequest

class ServoTuningParam(google.protobuf.message.Message):
    """servotuning/get_raw"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: typing.Text
    value: builtins.float
    def __init__(self,
        *,
        name: typing.Text = ...,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name",b"name","value",b"value"]) -> None: ...
global___ServoTuningParam = ServoTuningParam

class ParamsetInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    type: typing.Text
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServoTuningParam]: ...
    def __init__(self,
        *,
        type: typing.Text = ...,
        params: typing.Optional[typing.Iterable[global___ServoTuningParam]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params","type",b"type"]) -> None: ...
global___ParamsetInfo = ParamsetInfo

class SetServoTuningRequest(google.protobuf.message.Message):
    """servotuning/set_raw"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    PARAMSET_FIELD_NUMBER: builtins.int
    TUNING_PARAMS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    paramset: builtins.int
    @property
    def tuning_params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServoTuningParam]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        paramset: builtins.int = ...,
        tuning_params: typing.Optional[typing.Iterable[global___ServoTuningParam]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","paramset",b"paramset","tuning_params",b"tuning_params"]) -> None: ...
global___SetServoTuningRequest = SetServoTuningRequest

class LoadParamset(google.protobuf.message.Message):
    """servotuning/load_paramset"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    TO_PARAMSET_FIELD_NUMBER: builtins.int
    FROM_PARAMSET_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    to_paramset: builtins.int
    from_paramset: builtins.int
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        to_paramset: builtins.int = ...,
        from_paramset: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","from_paramset",b"from_paramset","interface_id",b"interface_id","to_paramset",b"to_paramset"]) -> None: ...
global___LoadParamset = LoadParamset

class SetServoTuningPIDRequest(google.protobuf.message.Message):
    """servotuning/set_pid"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    PARAMSET_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    I_FIELD_NUMBER: builtins.int
    D_FIELD_NUMBER: builtins.int
    FC_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    paramset: builtins.int
    p: builtins.float
    i: builtins.float
    d: builtins.float
    fc: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        paramset: builtins.int = ...,
        p: builtins.float = ...,
        i: builtins.float = ...,
        d: builtins.float = ...,
        fc: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","d",b"d","device",b"device","fc",b"fc","i",b"i","interface_id",b"interface_id","p",b"p","paramset",b"paramset"]) -> None: ...
global___SetServoTuningPIDRequest = SetServoTuningPIDRequest

class PidTuning(google.protobuf.message.Message):
    """servotuning/get_pid"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    P_FIELD_NUMBER: builtins.int
    I_FIELD_NUMBER: builtins.int
    D_FIELD_NUMBER: builtins.int
    FC_FIELD_NUMBER: builtins.int
    type: typing.Text
    version: builtins.int
    p: builtins.float
    i: builtins.float
    d: builtins.float
    fc: builtins.float
    def __init__(self,
        *,
        type: typing.Text = ...,
        version: builtins.int = ...,
        p: builtins.float = ...,
        i: builtins.float = ...,
        d: builtins.float = ...,
        fc: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["d",b"d","fc",b"fc","i",b"i","p",b"p","type",b"type","version",b"version"]) -> None: ...
global___PidTuning = PidTuning

class SetSimpleTuning(google.protobuf.message.Message):
    """servotuning/set_simple_tuning
    servotuning/is_using_simple_tuning
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    PARAMSET_FIELD_NUMBER: builtins.int
    CARRIAGE_MASS_FIELD_NUMBER: builtins.int
    LOAD_MASS_FIELD_NUMBER: builtins.int
    TUNING_PARAMS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    paramset: builtins.int
    carriage_mass: builtins.float
    load_mass: builtins.float
    @property
    def tuning_params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServoTuningParam]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        paramset: builtins.int = ...,
        carriage_mass: builtins.float = ...,
        load_mass: builtins.float = ...,
        tuning_params: typing.Optional[typing.Iterable[global___ServoTuningParam]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","carriage_mass",b"carriage_mass","device",b"device","interface_id",b"interface_id","load_mass",b"load_mass","paramset",b"paramset","tuning_params",b"tuning_params"]) -> None: ...
global___SetSimpleTuning = SetSimpleTuning

class SimpleTuningParamDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    MIN_LABEL_FIELD_NUMBER: builtins.int
    MAX_LABEL_FIELD_NUMBER: builtins.int
    DATA_TYPE_FIELD_NUMBER: builtins.int
    name: typing.Text
    min_label: typing.Text
    max_label: typing.Text
    data_type: typing.Text
    def __init__(self,
        *,
        name: typing.Text = ...,
        min_label: typing.Text = ...,
        max_label: typing.Text = ...,
        data_type: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_type",b"data_type","max_label",b"max_label","min_label",b"min_label","name",b"name"]) -> None: ...
global___SimpleTuningParamDefinition = SimpleTuningParamDefinition

class GetSimpleTuningParamDefinitionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SimpleTuningParamDefinition]: ...
    def __init__(self,
        *,
        params: typing.Optional[typing.Iterable[global___SimpleTuningParamDefinition]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___GetSimpleTuningParamDefinitionResponse = GetSimpleTuningParamDefinitionResponse

class TranslatorCreateRequest(google.protobuf.message.Message):
    """translator/create"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEFINITION_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def definition(self) -> global___TranslatorDefinition: ...
    @property
    def config(self) -> global___TranslatorConfig: ...
    def __init__(self,
        *,
        definition: typing.Optional[global___TranslatorDefinition] = ...,
        config: typing.Optional[global___TranslatorConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config",b"config","definition",b"definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config",b"config","definition",b"definition"]) -> None: ...
global___TranslatorCreateRequest = TranslatorCreateRequest

class TranslatorCreateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["translator_id",b"translator_id"]) -> None: ...
global___TranslatorCreateResponse = TranslatorCreateResponse

class TranslatorAxisDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PERIPHERAL_ID_FIELD_NUMBER: builtins.int
    MICROSTEP_RESOLUTION_FIELD_NUMBER: builtins.int
    peripheral_id: builtins.int
    microstep_resolution: builtins.int
    def __init__(self,
        *,
        peripheral_id: builtins.int = ...,
        microstep_resolution: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["microstep_resolution",b"microstep_resolution","peripheral_id",b"peripheral_id"]) -> None: ...
global___TranslatorAxisDefinition = TranslatorAxisDefinition

class TranslatorDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEVICE_ID_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    MAX_SPEED_FIELD_NUMBER: builtins.int
    device_id: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TranslatorAxisDefinition]: ...
    @property
    def max_speed(self) -> global___Measurement: ...
    def __init__(self,
        *,
        device_id: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[global___TranslatorAxisDefinition]] = ...,
        max_speed: typing.Optional[global___Measurement] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_speed",b"max_speed"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","device_id",b"device_id","max_speed",b"max_speed"]) -> None: ...
global___TranslatorDefinition = TranslatorDefinition

class TranslatorConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_MAPPINGS_FIELD_NUMBER: builtins.int
    AXIS_TRANSFORMATIONS_FIELD_NUMBER: builtins.int
    @property
    def axis_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TranslatorAxisMapping]: ...
    @property
    def axis_transformations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TranslatorAxisTransformation]: ...
    def __init__(self,
        *,
        axis_mappings: typing.Optional[typing.Iterable[global___TranslatorAxisMapping]] = ...,
        axis_transformations: typing.Optional[typing.Iterable[global___TranslatorAxisTransformation]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_mappings",b"axis_mappings","axis_transformations",b"axis_transformations"]) -> None: ...
global___TranslatorConfig = TranslatorConfig

class TranslatorAxisMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_LETTER_FIELD_NUMBER: builtins.int
    AXIS_INDEX_FIELD_NUMBER: builtins.int
    axis_letter: typing.Text
    axis_index: builtins.int
    def __init__(self,
        *,
        axis_letter: typing.Text = ...,
        axis_index: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_index",b"axis_index","axis_letter",b"axis_letter"]) -> None: ...
global___TranslatorAxisMapping = TranslatorAxisMapping

class TranslatorAxisTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AXIS_LETTER_FIELD_NUMBER: builtins.int
    SCALING_FIELD_NUMBER: builtins.int
    TRANSLATION_FIELD_NUMBER: builtins.int
    axis_letter: typing.Text
    scaling: builtins.float
    @property
    def translation(self) -> global___Measurement: ...
    def __init__(self,
        *,
        axis_letter: typing.Text = ...,
        scaling: builtins.float = ...,
        translation: typing.Optional[global___Measurement] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["translation",b"translation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis_letter",b"axis_letter","scaling",b"scaling","translation",b"translation"]) -> None: ...
global___TranslatorAxisTransformation = TranslatorAxisTransformation

class TranslatorTranslateRequest(google.protobuf.message.Message):
    """translator/translate
    translator/translate_live
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    block: typing.Text
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        block: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["block",b"block","translator_id",b"translator_id"]) -> None: ...
global___TranslatorTranslateRequest = TranslatorTranslateRequest

class TranslateMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MESSAGE_FIELD_NUMBER: builtins.int
    FROM_BLOCK_FIELD_NUMBER: builtins.int
    TO_BLOCK_FIELD_NUMBER: builtins.int
    message: typing.Text
    from_block: builtins.int
    to_block: builtins.int
    def __init__(self,
        *,
        message: typing.Text = ...,
        from_block: builtins.int = ...,
        to_block: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_block",b"from_block","message",b"message","to_block",b"to_block"]) -> None: ...
global___TranslateMessage = TranslateMessage

class TranslatorTranslateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMANDS_FIELD_NUMBER: builtins.int
    WARNINGS_FIELD_NUMBER: builtins.int
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def warnings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TranslateMessage]: ...
    def __init__(self,
        *,
        commands: typing.Optional[typing.Iterable[typing.Text]] = ...,
        warnings: typing.Optional[typing.Iterable[global___TranslateMessage]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commands",b"commands","warnings",b"warnings"]) -> None: ...
global___TranslatorTranslateResponse = TranslatorTranslateResponse

class GCodeSyntaxExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FROM_BLOCK_FIELD_NUMBER: builtins.int
    TO_BLOCK_FIELD_NUMBER: builtins.int
    from_block: builtins.int
    to_block: builtins.int
    def __init__(self,
        *,
        from_block: builtins.int = ...,
        to_block: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_block",b"from_block","to_block",b"to_block"]) -> None: ...
global___GCodeSyntaxExceptionData = GCodeSyntaxExceptionData

class GCodeExecutionExceptionData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FROM_BLOCK_FIELD_NUMBER: builtins.int
    TO_BLOCK_FIELD_NUMBER: builtins.int
    from_block: builtins.int
    to_block: builtins.int
    def __init__(self,
        *,
        from_block: builtins.int = ...,
        to_block: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_block",b"from_block","to_block",b"to_block"]) -> None: ...
global___GCodeExecutionExceptionData = GCodeExecutionExceptionData

class TranslatorFlushLiveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    WAIT_UNTIL_IDLE_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    wait_until_idle: builtins.bool
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        wait_until_idle: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["translator_id",b"translator_id","wait_until_idle",b"wait_until_idle"]) -> None: ...
global___TranslatorFlushLiveRequest = TranslatorFlushLiveRequest

class TranslatorFlushResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COMMANDS_FIELD_NUMBER: builtins.int
    @property
    def commands(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        commands: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commands",b"commands"]) -> None: ...
global___TranslatorFlushResponse = TranslatorFlushResponse

class TranslatorCreateLiveRequest(google.protobuf.message.Message):
    """translator/create_live"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    STREAM_ID_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    stream_id: builtins.int
    @property
    def config(self) -> global___TranslatorConfig: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        stream_id: builtins.int = ...,
        config: typing.Optional[global___TranslatorConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config",b"config","device",b"device","interface_id",b"interface_id","stream_id",b"stream_id"]) -> None: ...
global___TranslatorCreateLiveRequest = TranslatorCreateLiveRequest

class TranslatorCreateFromDeviceRequest(google.protobuf.message.Message):
    """translator/create_from_device"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXES_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    @property
    def axes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def config(self) -> global___TranslatorConfig: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axes: typing.Optional[typing.Iterable[builtins.int]] = ...,
        config: typing.Optional[global___TranslatorConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config",b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["axes",b"axes","config",b"config","device",b"device","interface_id",b"interface_id"]) -> None: ...
global___TranslatorCreateFromDeviceRequest = TranslatorCreateFromDeviceRequest

class TranslatorEmptyRequest(google.protobuf.message.Message):
    """gcode/free"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["translator_id",b"translator_id"]) -> None: ...
global___TranslatorEmptyRequest = TranslatorEmptyRequest

class TranslatorSetTraverseRateRequest(google.protobuf.message.Message):
    """gcode/set_traverse_rate"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    TRAVERSE_RATE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    traverse_rate: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        traverse_rate: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["translator_id",b"translator_id","traverse_rate",b"traverse_rate","unit",b"unit"]) -> None: ...
global___TranslatorSetTraverseRateRequest = TranslatorSetTraverseRateRequest

class TranslatorSetAxisPositionRequest(google.protobuf.message.Message):
    """gcode/get_axis_position
    gcode/set_axis_position
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    axis: typing.Text
    position: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        axis: typing.Text = ...,
        position: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","position",b"position","translator_id",b"translator_id","unit",b"unit"]) -> None: ...
global___TranslatorSetAxisPositionRequest = TranslatorSetAxisPositionRequest

class TranslatorGetAxisPositionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    axis: typing.Text
    unit: typing.Text
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        axis: typing.Text = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","translator_id",b"translator_id","unit",b"unit"]) -> None: ...
global___TranslatorGetAxisPositionRequest = TranslatorGetAxisPositionRequest

class TranslatorGetAxisOffsetRequest(google.protobuf.message.Message):
    """gcode/get_axis_offset"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    COORDINATE_SYSTEM_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    coordinate_system: typing.Text
    axis: typing.Text
    unit: typing.Text
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        coordinate_system: typing.Text = ...,
        axis: typing.Text = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","coordinate_system",b"coordinate_system","translator_id",b"translator_id","unit",b"unit"]) -> None: ...
global___TranslatorGetAxisOffsetRequest = TranslatorGetAxisOffsetRequest

class TranslatorSetFeedRateOverrideRequest(google.protobuf.message.Message):
    """gcode/set_feed_rate_override"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRANSLATOR_ID_FIELD_NUMBER: builtins.int
    COEFFICIENT_FIELD_NUMBER: builtins.int
    translator_id: builtins.int
    coefficient: builtins.float
    def __init__(self,
        *,
        translator_id: builtins.int = ...,
        coefficient: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["coefficient",b"coefficient","translator_id",b"translator_id"]) -> None: ...
global___TranslatorSetFeedRateOverrideRequest = TranslatorSetFeedRateOverrideRequest

class DeviceSetStorageRequest(google.protobuf.message.Message):
    """device/set_storage"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    ENCODE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    value: typing.Text
    encode: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        value: typing.Text = ...,
        encode: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","encode",b"encode","interface_id",b"interface_id","key",b"key","value",b"value"]) -> None: ...
global___DeviceSetStorageRequest = DeviceSetStorageRequest

class DeviceGetStorageRequest(google.protobuf.message.Message):
    """device/get_storage"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    DECODE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    decode: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        decode: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","decode",b"decode","device",b"device","interface_id",b"interface_id","key",b"key"]) -> None: ...
global___DeviceGetStorageRequest = DeviceGetStorageRequest

class DeviceSetStorageNumberRequest(google.protobuf.message.Message):
    """device/set_storage_number"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    value: builtins.float
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        value: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","key",b"key","value",b"value"]) -> None: ...
global___DeviceSetStorageNumberRequest = DeviceSetStorageNumberRequest

class DeviceSetStorageBoolRequest(google.protobuf.message.Message):
    """device/set_storage_bool"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    value: builtins.bool
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        value: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","key",b"key","value",b"value"]) -> None: ...
global___DeviceSetStorageBoolRequest = DeviceSetStorageBoolRequest

class DeviceStorageRequest(google.protobuf.message.Message):
    """device/get_storage_number
    device/get_storage_bool
    device/erase_storage
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","device",b"device","interface_id",b"interface_id","key",b"key"]) -> None: ...
global___DeviceStorageRequest = DeviceStorageRequest

class DeviceSetUnitConversionsRequest(google.protobuf.message.Message):
    """device/set_unit_conversions"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_ID_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    AXIS_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    CONVERSIONS_FIELD_NUMBER: builtins.int
    interface_id: builtins.int
    device: builtins.int
    axis: builtins.int
    key: typing.Text
    @property
    def conversions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConversionFactor]: ...
    def __init__(self,
        *,
        interface_id: builtins.int = ...,
        device: builtins.int = ...,
        axis: builtins.int = ...,
        key: typing.Text = ...,
        conversions: typing.Optional[typing.Iterable[global___ConversionFactor]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["axis",b"axis","conversions",b"conversions","device",b"device","interface_id",b"interface_id","key",b"key"]) -> None: ...
global___DeviceSetUnitConversionsRequest = DeviceSetUnitConversionsRequest

class ConversionFactor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SETTING_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    setting: typing.Text
    value: builtins.float
    unit: typing.Text
    def __init__(self,
        *,
        setting: typing.Text = ...,
        value: builtins.float = ...,
        unit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["setting",b"setting","unit",b"unit","value",b"value"]) -> None: ...
global___ConversionFactor = ConversionFactor
